@@ -45,10 +45,23 @@ setGeneric("pk", function (x) standardGeneric("pk"))
 setGeneric("pk<-", function (x, value) standardGeneric("pk<-"))
 setGeneric("digits", function (x) standardGeneric("digits"))
 setGeneric("digits<-", function (x, value) standardGeneric("digits<-"))
+setGeneric("transforms", function (x) standardGeneric("transforms"))
+setGeneric("transforms<-", function (x, value) standardGeneric("transforms<-"))
+setGeneric("showTransforms", function (x) standardGeneric("showTransforms"))
 setGeneric("geo", function (x) standardGeneric("geo"))
 setGeneric("geo<-", function (x, value) standardGeneric("geo<-"))
 setGeneric("fetchGeoFile", function (x) standardGeneric("fetchGeoFile"))
-
+setGeneric("anchor", function (x, ...) standardGeneric("anchor"))
+setGeneric("anchors", function (x) standardGeneric("anchors"))
+setGeneric("anchor<-", function (x, value) standardGeneric("anchor<-"))
+setGeneric("arguments", function (x, ...) standardGeneric("arguments"))
+setGeneric("arguments<-", function (x, value) standardGeneric("arguments<-"))
+setGeneric("func", function (x) standardGeneric("func"))
+setGeneric("funcs", function (x) standardGeneric("funcs"))
+setGeneric("subtotals", function (x, ...) standardGeneric("subtotals"))
+setGeneric("subtotals<-", function (x, value) standardGeneric("subtotals<-"))
+setGeneric("makeInsertion", function (x, var_categories) standardGeneric("makeInsertion"))
+setGeneric("subtotalArray", function (x, ...) standardGeneric("subtotalArray"))
 
 setGeneric("types", function (x) standardGeneric("types"))
 setGeneric("timestamps", function (x) standardGeneric("timestamps"))
@@ -145,9 +158,11 @@ setGeneric("dimnames")
 setGeneric("margin.table")
 setGeneric("prop.table")
 setGeneric("round")
+setGeneric("rstandard")
 
 setGeneric("bases", function (x, margin=NULL) standardGeneric("bases"))
 setGeneric("dimensions", function (x) standardGeneric("dimensions"))
+setGeneric("dimensions<-", function (x, value) standardGeneric("dimensions<-"))
 setGeneric("measures", function (x) standardGeneric("measures"))
 
 setGeneric("subset")
