@@ -28,6 +28,8 @@
 #' @param cases a list of lists with each case condition to use each must
 #' include at least a `name` and an `expression` element. Cases may also include
 #' `missing` (logical) and `numeric_value` (numeric).
+#' @param data (optional) a crunch dataset to use. Specifying this means you
+#' don't have to put `dataset$` in front of each variable name.
 #' @param name a character to use as the name of the case variable to create
 #'
 #' @return A [`VariableDefinition`] that will create the new
@@ -45,11 +47,17 @@
 #'                             list(expression="else", name="other")),
 #'                  name="new case")
 #' makeCaseVariable(case1=ds$v1 == 1, case2=ds$v2 == 2, other="else", name="new case")
+#'
+#' # the dataset can be specified with data=
+#' makeCaseVariable(case1=v1 == 1, case2=v2 == 2, data=ds, name="new case")
 #' }
 #' @export
-makeCaseVariable <- function (..., cases, name) {
+makeCaseVariable <- function (..., cases, data = NULL, name) {
     ## Gather the new variable's metadata fields (and possibly expressions)
-    casevar <- list(..., name=name)
+    # -1 to remove the list primative
+    dots <- as.list(substitute(list(...)))[-1L]
+    casevar <- lapply(dots, evalSide, dat = data, eval_env = parent.frame())
+    casevar$name <- name
     is_expr <- function (x) {
         inherits(x, "CrunchLogicalExpr") || x %in% magic_else_string
     }
@@ -58,7 +66,8 @@ makeCaseVariable <- function (..., cases, name) {
         if (missing(cases)) {
             ## Remove the expressions from the variable definition
             casevar <- Filter(Negate(is_expr), casevar)
-            cases <- mapply(function (e, n) list(name=n, expression=e),
+            cases <- mapply(function (e, n) list(name=n,
+                                                 expression=e),
                             e=exprs, n=names(exprs),
                             SIMPLIFY = FALSE, USE.NAMES = FALSE)
         } else {
@@ -66,11 +75,14 @@ makeCaseVariable <- function (..., cases, name) {
                  " as well as in the ", dQuote("cases"), " argument, please use ",
                  "one or the other.")
          }
-    } else if (missing(cases) || length(cases) == 0) {
+    } else if (missing(cases) || substitute(cases) == "") {
+        # check substitute(cases) == "" in case the cases need to be
+        # evaluated, length 1 means no cases are present.
         halt("must supply case conditions in either ", dQuote("..."), " or ",
              "the ", dQuote("cases"), " argument, please use one or the other.")
     }
 
+    cases <- evalSide(substitute(cases), data, parent.frame())
     cases <- ensureValidCases(cases)
 
     # create the new categorical variable
@@ -154,17 +166,18 @@ ensureValidCase <- function (case) {
     defaults <- list(id=NULL, name=NULL, expression=NULL,
                      numeric_value=NULL, missing=FALSE)
     wrong_case_names <- setdiff(names(case), names(defaults))
-    if (length(wrong_case_names) > 0) {
-        halt("each case must have at most an id, name, expression, ",
-             "numeric_value, and missing element. The errant arguments were: ",
-             serialPaste(wrong_case_names))
-    } else if (is.null(wrong_case_names)) {
+    if (is.null(wrong_case_names) || "" %in% names(case)) {
         # if no names are found, some thing is wrong with the format of cases.
         # one possibility is that someone is trying to embed the cases too
         # many times, or that else_cases has more than one case.
-        halt("could not find names for a case; this might be because the ",
-             "cases were embedded in too many lists. The first offending ",
-             "case is:\n", case)
+        halt("could not find correct names for a case; this might be because ",
+             "the cases were embedded in too many lists or because not all ",
+             "the elements of the cases have names. The first offending case ",
+             "is:\n", case)
+    } else if (length(wrong_case_names) > 0) {
+        halt("each case must have at most an id, name, expression, ",
+             "numeric_value, and missing element. The errant arguments were: ",
+             serialPaste(wrong_case_names))
     }
     # set defaults
     case <- modifyList(defaults, case)
