@@ -16,13 +16,6 @@ setValidity("Categories", function (object) {
     return(TRUE)
 })
 
-setMethod("initialize", "Categories", function (.Object, ...) {
-    .Object@.Data <- lapply(..1,
-        function (x) try(Category(data=x), silent=TRUE))
-    validObject(.Object)
-    return(.Object)
-})
-
 is.categories <- function (x) inherits(x, "Categories")
 
 concatenateCategories <- function (...) {
@@ -57,34 +50,6 @@ c.Categories <- concatenateCategories
 #' @export
 c.Category <- concatenateCategories
 
-#' @rdname Categories
-#' @export
-setMethod("[", c("Categories", "ANY"), function (x, i, ...) {
-    x@.Data <- x@.Data[i]
-    return(x)
-})
-
-#' @rdname Categories
-#' @export
-setMethod("[", c("Categories", "character"), function (x, i, ...) {
-    indices <- match(i, names(x))
-    if (any(is.na(indices))) {
-        halt("subscript out of bounds: ", serialPaste(i[is.na(indices)]))
-    }
-    callNextMethod(x, i=indices)
-})
-
-#' @rdname Categories
-#' @export
-setMethod("[", c("Categories", "numeric"), function (x, i, ...) {
-    invalid.indices <- setdiff(abs(i), seq_along(x@.Data))
-    if (length(invalid.indices)) {
-        halt("subscript out of bounds: ", serialPaste(invalid.indices))
-    }
-    x@.Data <- x@.Data[i]
-    return(x)
-})
-
 #' @rdname Categories
 #' @export
 setMethod("[<-", c("Categories", "ANY"), function (x, i, ..., value) {
@@ -92,43 +57,7 @@ setMethod("[<-", c("Categories", "ANY"), function (x, i, ..., value) {
     return(x)
 })
 
-#' @rdname Categories
-#' @export
-setMethod("names", "Categories", function (x) vapply(x, name, character(1)))
 
-#' @rdname Categories
-#' @export
-setMethod("values", "Categories", function (x) vapply(x, value, numeric(1)))
-
-#' @rdname Categories
-#' @export
-setMethod("ids", "Categories", function (x) vapply(x, id, integer(1)))
-
-setNames <- function (x, value) {
-    if (is.null(value) || !is.character(value)) {
-        halt('Names must be of class "character"')
-    }
-    if (!identical(length(x), length(value))) {
-        halt("Invalid names: supplied ", length(value), " names for ",
-            length(x), " categories")
-    }
-    if (any(is.na(value))) {
-        halt("Category names must be non-missing")
-    }
-    x[] <- mapply(setName, x, value=value, SIMPLIFY=FALSE)
-    return(x)
-}
-setValues <- function (x, value) {
-    x[] <- mapply(setValue, x[], value=value, SIMPLIFY=FALSE)
-    return(x)
-}
-
-#' @rdname Categories
-#' @export
-setMethod("names<-", "Categories", setNames)
-#' @rdname Categories
-#' @export
-setMethod("values<-", "Categories", setValues)
 #' @rdname Categories
 #' @export
 setMethod("ids<-", "Categories", function (x, value) {
@@ -182,11 +111,6 @@ setMethod("na.omit", "Categories", function (object, ...) {
 #' @name is-na-categories
 NULL
 
-#' @rdname is-na-categories
-#' @aliases is-na-categories
-#' @export
-setMethod("is.na", "Categories", function (x) structure(vapply(x, is.na, logical(1), USE.NAMES=FALSE), .Names=names(x)))
-
 #' is.selected for Categories
 #'
 #' Crunch Multiple Response variables identify one or more categories as "selected".
@@ -203,6 +127,24 @@ setMethod("is.na", "Categories", function (x) structure(vapply(x, is.na, logical
 #' @aliases is.selected<-
 NULL
 
+setValues <- function (x, value) {
+    x[] <- mapply(setValue, x[], value=value, SIMPLIFY=FALSE)
+    return(x)
+}
+
+#' @rdname Categories
+#' @export
+setMethod("values", "Categories", function (x) vapply(x, value, numeric(1)))
+
+#' @rdname Categories
+#' @export
+setMethod("values<-", "Categories", setValues)
+
+#' @rdname is-na-categories
+#' @aliases is-na-categories
+#' @export
+setMethod("is.na", "Categories", function (x) structure(vapply(x, is.na, logical(1), USE.NAMES=FALSE), .Names=names(x)))
+
 #' @rdname is-selected-categories
 #' @export
 setMethod("is.selected", "Categories", function (x) structure(vapply(x, is.selected, logical(1), USE.NAMES=FALSE), .Names=names(x)))
@@ -216,14 +158,38 @@ setMethod("is.selected<-", "Categories", function (x, value) {
     if (length(value) != length(x)) {
         halt("You supplied ", length(value), " logical values for ", length(x), " Categories.")
     }
-
+    
     x@.Data <- mapply(function (x, value) {
-            is.selected(x) <- value
-            return(x)
-        }, x=x@.Data, value=value, USE.NAMES=FALSE, SIMPLIFY=FALSE)
+        is.selected(x) <- value
+        return(x)
+    }, x=x@.Data, value=value, USE.NAMES=FALSE, SIMPLIFY=FALSE)
     return(x)
 })
 
+#' @rdname is-na-categories
+#' @aliases is-na-categories
+#' @export
+setMethod("is.na", "Categories", function (x) structure(vapply(x, is.na, logical(1), USE.NAMES=FALSE), .Names=names(x)))
+
+#' @rdname is-na-categories
+#' @export
+setMethod("is.na<-", c("Categories", "character"), function (x, value) {
+    ix <- match(value, names(x))
+    out <- handleMissingCategoryLookup(ix, value, strict=TRUE)
+    x[ix] <- lapply(x[ix], `is.na<-`, value=TRUE)
+    return(x)
+})
+
+#' @rdname is-na-categories
+#' @export
+setMethod("is.na<-", c("Categories", "logical"), function (x, value) {
+    stopifnot(length(x) == length(value))
+    x@.Data <- mapply(function (x, value) {
+        is.na(x) <- value
+        return(x)
+    }, x=x@.Data, value=value, USE.NAMES=FALSE, SIMPLIFY=FALSE)
+    return(x)
+})
 
 n2i <- function (x, cats, strict=TRUE) {
     ## Convert x from category names to the corresponding category ids
@@ -257,26 +223,6 @@ handleMissingCategoryLookup <- function (result, original, strict=TRUE) {
     return(result)
 }
 
-#' @rdname is-na-categories
-#' @export
-setMethod("is.na<-", c("Categories", "character"), function (x, value) {
-    ix <- match(value, names(x))
-    out <- handleMissingCategoryLookup(ix, value, strict=TRUE)
-    x[ix] <- lapply(x[ix], `is.na<-`, value=TRUE)
-    return(x)
-})
-
-#' @rdname is-na-categories
-#' @export
-setMethod("is.na<-", c("Categories", "logical"), function (x, value) {
-    stopifnot(length(x) == length(value))
-    x@.Data <- mapply(function (x, value) {
-            is.na(x) <- value
-            return(x)
-        }, x=x@.Data, value=value, USE.NAMES=FALSE, SIMPLIFY=FALSE)
-    return(x)
-})
-
 addNoDataCategory <- function (variable) {
     cats <- ensureNoDataCategory(categories(variable))
     if (is.subvariable(variable)) {
@@ -298,80 +244,3 @@ ensureNoDataCategory <- function (cats) {
         return(c(cats, Category(data=.no.data)))
     }
 }
-
-setMethod("lapply", "Categories", function (X, FUN, ...) {
-    X@.Data <- lapply(X@.Data, FUN, ...)
-    return(X)
-})
-
-#' Change the id of a category for a categorical variable
-#'
-#' Changes the id of a category from an existing value to a new one.
-#' The variable can be a categorical, categorical array, or multiple response
-#' variable. The category changed will have the same numeric value and missing
-#' status as before. The one exception to this is if the numeric value is the
-#' same as the id, then the new numeric value will be the same as the new id.
-#'
-#' @param variable the variable in a crunch dataset that will be changed (note: the variable must be categorical, categorical array, or multiple response)
-#' @param from the (old) id identifying the category you want to change
-#' @param to the (new) id for the category
-#' @return `variable` with category `from` and all associated data values mapped to id `to`
-#' @examples
-#' \dontrun{
-#' ds$country <- changeCategoryID(ds$country, 2, 6)
-#' }
-#' @export
-changeCategoryID <- function (variable, from, to) {
-    if (!has.categories(variable)) {
-        halt("The variable ", name(variable), " doesn't have categories.")
-    }
-
-    if (!is.numeric(from) & length(from) == 1) {
-        halt("from should be a single numeric")
-    }
-
-    if (!is.numeric(to) &  length(to) == 1) {
-        halt("to should be a single numeric")
-    }
-
-    pos.from <- match(from, ids(categories(variable)))
-    if (is.na(pos.from)) {
-        halt("No category with id ", from)
-    }
-
-    if (to %in% ids(categories(variable))) {
-        halt("Id ", to, " is already a category, please provide a new category id.")
-    }
-
-    ## Add new category
-    newcat <- categories(variable)[[pos.from]]
-    # if the old id matches the old numeric value, likely the user wants these
-    # to be the same, so change the new numeric value to be the same as the
-    # new id.
-    if (newcat$id == newcat$numeric_value %||% FALSE) {
-        newcat$numeric_value <- to
-    }
-    newcat$id <- to
-
-    names(categories(variable))[pos.from] <- "__TO_DELETE__"
-    categories(variable) <- c(categories(variable), newcat)
-
-    ## Move data to that new id
-    if (is.Categorical(variable)) {
-        variable[variable == from] <- to
-    } else if (is.Array(variable)) {
-        # If the variable is an array, then lapply over the subvariables
-        # TODO: change iteration over shojicatalogs to allow iterating over the variable directly
-        lapply(names(variable), function (subvarname) {
-            variable[[subvarname]][variable[[subvarname]] == from] <- to
-        })
-    }
-
-    ## Delete old category
-    keep <- seq_along(categories(variable))
-    keep[pos.from] <- length(keep)
-    keep <- keep[-length(keep)]
-    categories(variable) <- categories(variable)[keep]
-
-    invisible(variable)
-}
