@@ -1,7 +1,11 @@
-#' Filter entities for a dataset
+#' Get or set a dataset's filters
+#'
+#' You can build and save filters in the Crunch web app, and these filters
+#' are stored in a `FilterCatalog`. This function allows you to retrieve
+#' and modify those filters.
 #'
 #' @param x a CrunchDataset
-#' @param value for the assignment method, a FilterCatalog
+#' @param value for the setter, a FilterCatalog
 #' @return an object of class FilterCatalog containing references to Filter
 #' entities usable in the web application. (Setter returns the Dataset.)
 #' @name filter-catalog
@@ -20,12 +24,15 @@ setMethod("filters<-", "CrunchDataset", function (x, value) x)
 
 #' View and modify "public" attribute
 #'
+#' View and modify whether all dataset viewers have access to the dataset. This
+#' will return `FALSE` if the dataset is in draft.
+#'
 #' @param x a Crunch object
 #' @param value an attribute to set
-#' @return For \code{is.public}, a logical value for whether the object is
+#' @return For `is.public`, a logical value for whether the object is
 #' flagged as shared with all dataset viewers. (Its setter thus takes a
-#' logical value as well.) Catalogs return a vector of logicals corresponding
-#' to the length of the catalog, while entities return a single value.
+#' logical value as well.) Catalogs of datasets return a vector of logicals
+#' corresponding to the length of the catalog, while entities return a single value.
 #' @name is-public
 #' @aliases is.public<- is.public
 NULL
@@ -37,6 +44,7 @@ setMethod("is.public", "CrunchFilter", function (x) x@body$is_public)
 #' @rdname is-public
 #' @export
 setMethod("is.public<-", "CrunchFilter", function (x, value) {
+    stopifnot(is.TRUEorFALSE(value))
     setEntitySlot(x, "is_public", value)
 })
 
@@ -65,17 +73,17 @@ setMethod("[[<-", c("FilterCatalog", "character", "missing", "CrunchLogicalExpr"
 
 #' Create a new filter
 #'
-#' This function creates a new filter. You can achieve the same results by
-#' assigning into a dataset's filters catalog, but this may be a more natural
+#' This function creates a new filter for a CrunchDataset. You can achieve the same results
+#' by assigning into a dataset's filters catalog using[filters()], but this may be a more natural
 #' way to think of the action, particularly when you want to do something with
 #' the filter entity after you create it.
 #' @param name character name for the filter
 #' @param expression CrunchLogicalExpr with which to make a filter entity
 #' @param catalog FilterCatalog in which to create the new filter. May also
 #' provide a dataset entity. If omitted, the function will attempt to infer the
-#' dataset (and thus its FilterCatalog) from the contents of \code{expression}.
-#' @param ... Additional filter attributes to set. Options include \code{is_public}.
-#' @return A \code{CrunchFilter} object.
+#' dataset (and thus its FilterCatalog) from the contents of `expression`.
+#' @param ... Additional filter attributes to set, such as `is_public`.
+#' @return A `CrunchFilter` object.
 #' @export
 newFilter <- function (name, expression, catalog=NULL, ...) {
     if (is.null(catalog)) {
@@ -152,10 +160,8 @@ setMethod("appliedFilters", "CrunchDataset", function (x) {
 
 setMethod("appliedFilters<-", c("CrunchDataset", "CrunchFilter"),
     function (x, value) {
-        b <- toJSON(list(
-            graph=I(list(self(value)))
-        ))
-        crPUT(shojiURL(x, "views", "applied_filters"), body=b)
+        b <- list(graph=I(list(self(value))))
+        crPUT(shojiURL(x, "views", "applied_filters"), body=toJSON(b))
         return(x)
     })
 
@@ -241,7 +247,7 @@ exclusion <- function (x) {
         ## Server is returning variable IDs. Make them into URLs
         ## TODO: remove this
         e <- idsToURLs(e, variableCatalogURL(x))
-        return(CrunchLogicalExpr(expression=e))
+        return(CrunchLogicalExpr(expression=e, dataset_url=self(x)))
     } else {
         return(NULL)
     }
