@@ -38,11 +38,37 @@ setMethod("show", "Category", .showIt)
 setMethod("show", "Categories", .showIt)
 
 
+#' @rdname show-crunch
+#' @export
+setMethod("show", "Insertion", .showIt)
+
+#' @rdname show-crunch
+#' @export
+setMethod("show", "Insertions", .showIt)
+
 # Actual show methods
 
-showCategory <- function (x) data.frame(id=id(x), name=name(x), value=value(x), missing=is.na(x))
+showAbsCategory <- function (x) data.frame(id=id(x), name=name(x), value=value(x), missing=is.na(x), stringsAsFactors = FALSE)
+showAbsCategories <- function (x) do.call("rbind", lapply(x, showAbsCategory))
+
+showInsertion <- function (x) {
+    df_out <- data.frame(anchor=anchor(x), name=name(x),
+               func=func(x), args=serialPaste(arguments(x)), stringsAsFactors = FALSE)
+}
+showInsertions <- function (x) do.call("rbind",
+                                       c(lapply(x, getShowContent),
+                                         stringsAsFactors = FALSE))
+
+showSubtotalHeading <- function (x) {
+    # if anchor or args error because a categories object is not available to
+    # translate from category names to ids, then show the names without error
+    # for the show method only.
+    anchor <- tryCatch(anchor(x), error = function(e) {return(x$after)})
+    args <- tryCatch(arguments(x), error = function(e) {return(x$categories)})
+    df_out <- data.frame(anchor=anchor, name=name(x),
+                         func=func(x), args=serialPaste(args), stringsAsFactors = FALSE)
+}
 
-showCategories <- function (x) do.call("rbind", lapply(x, showCategory))
 
 showCrunchVariableTitle <- function (x) {
     out <- paste(getNameAndType(x), collapse=" ")
@@ -261,7 +287,22 @@ showMultitable <- function (x) {
     # eg remove selected_array()
     out <- c(out, "Column variables:",
              vapply(x@body$template, function (expr) {
-                 paste0("  ", formatExpression(expr$query[[1]]))
+                 if ("each" %in% names(expr$query[[1]])) {
+                     # if the first element of the query is each, then this is
+                     # an array so take the second argument instead.
+                     exprToFormat <- expr$query[[2]]
+
+                     # if the second arg is a as_selected or selected_array take
+                     # the variable from that to display var only
+                     mr_funcs <- c("as_selected", "selected_array")
+                     if ((exprToFormat[["function"]] %||% "") %in% mr_funcs ) {
+                         exprToFormat <- exprToFormat$args[[1]]
+                     }
+
+                     return(paste0("  ", formatExpression(exprToFormat)))
+                 }
+
+                 return(paste0("  ", formatExpression(expr$query[[1]])))
              }, character(1)))
 
     return(c(out))
@@ -269,8 +310,12 @@ showMultitable <- function (x) {
 
 # More boilerplate
 
-setMethod("getShowContent", "Category", showCategory)
-setMethod("getShowContent", "Categories", showCategories)
+setMethod("getShowContent", "AbstractCategory", showAbsCategory)
+setMethod("getShowContent", "AbstractCategories", showAbsCategories)
+setMethod("getShowContent", "Insertion", showInsertion)
+setMethod("getShowContent", "Insertions", showInsertions)
+setMethod("getShowContent", "Subtotal", showSubtotalHeading)
+setMethod("getShowContent", "Heading", showSubtotalHeading)
 setMethod("getShowContent", "CrunchVariable", showCrunchVariable)
 setMethod("getShowContent", "CategoricalArrayVariable",
     showCategoricalArrayVariable)
@@ -298,7 +343,7 @@ setMethod("getShowContent", "CrunchFilter",
     })
 #' @rdname show-crunch
 #' @export
-setMethod("show", "CrunchCube", function (object) show(cubeToArray(object)))
+setMethod("show", "CrunchCube", function (object) showTransforms(object))
 
 #' @rdname show-crunch
 #' @export
