@@ -33,8 +33,19 @@ NULL
 setMethod("subvariables", "CategoricalArrayVariable", function (x) {
     tup <- tuple(x)
     catalog_url <- absoluteURL(tup$subvariables_catalog, base=tup@index_url)
-    vars <- VariableCatalog(crGET(catalog_url))
-    out <- Subvariables(vars[subvariables(tup)])
+    if (!is.null(tup$subreferences)) {
+        ## This is from a rich `variableMetadata` catalog. Don't do any more GETs
+        subvars <- tup$subreferences
+        ## Subreferences names are ids. Convert to URLs
+        names(subvars) <- paste0(absoluteURL(names(subvars), base=catalog_url), "/")
+        out <- Subvariables(
+            index=subvars[tup$subvariables],
+            self=catalog_url
+        )
+    } else {
+        vars <- VariableCatalog(crGET(catalog_url))
+        out <- Subvariables(vars[subvariables(tup)])
+    }
     activeFilter(out) <- activeFilter(x)
     return(out)
 })
