@@ -123,6 +123,38 @@ with_mock_crunch({
             list(list(name="Both", categories=NULL))),
             "Combinations must reference 'categories' by name or id")
     })
+
+    test_that("collapseCategories errors correctly", {
+        expect_error(collapseCategories(ds$birthyr, "from", "to"),
+            "Variable must be a categorical.")
+        expect_error(collapseCategories(ds$gender, "Male", 1),
+            "Destination category must be a character string of length 1.")
+        expect_error(collapseCategories(ds$gender, "Male", c("young", "old")),
+            "Destination category must be a character string of length 1.")
+        expect_error(collapseCategories(ds$gender, 1, "young"),
+            paste0(dQuote('from'), " must be a character vector."))
+        expect_error(collapseCategories(ds$gender, "female", "woman"),
+            "female is not present in variable categories.")
+    })
+    test_that("collapseCategories takes no action when from and to are the same", {
+        expect_no_request(collapseCategories(ds$location, "London", "London"))
+    })
+    test_that("collapseCategories updates categories when merging into a new category", {
+        expect_PATCH(var <- collapseCategories(ds$location, c("London", "Scotland"), "GB"),
+            "https://app.crunch.io/api/datasets/1/variables/location/",
+            '{"categories":[{"id":1,"missing":false,"name":"London","numeric_value":1},{"id":2,"missing":false,"name":"Scotland","numeric_value":2},{"id":-1,"missing":true,"name":"No Data","numeric_value":null},{"id":3,"name":"GB"}]}'        )
+    })
+    test_that("collapseCategories updates the variable", {
+        expect_POST(var <- collapseCategories(ds$location, "Scotland", "London"),
+            "https://app.crunch.io/api/datasets/1/table/",
+            '{"command":"update","variables":{"https://app.crunch.io/api/datasets/1/variables/location/":{"value":1}},"filter":{"function":"==","args":[{"variable":"https://app.crunch.io/api/datasets/1/variables/location/"},{"value":2}]}}'
+        )
+    })
+    test_that("collapseCategories modifies category name", {
+        expect_PATCH(categories(ds$gender) <- collapseCategories(ds$gender, "Female", "woman"),
+            'https://app.crunch.io/api/datasets/1/variables/gender/',
+            '{"categories":[{"id":1,"missing":false,"name":"Male","numeric_value":1},{"id":2,"missing":false,"name":"woman","numeric_value":2},{"id":-1,"missing":true,"name":"No Data","numeric_value":null}]}'        )
+    })
 })
 
 with_test_authentication({
@@ -151,7 +183,7 @@ with_test_authentication({
         ds <- releaseAndReload(ds)
         expect_equivalent(as.array(crtabs(~ q1, data=ds)),
             array(c(6, 4, 10), dim=3,
-            dimnames=list(q1=c("Cat", "Dog", "Bird"))))
+                dimnames=list(q1=c("Cat", "Dog", "Bird"))))
         expect_equivalent(as.array(crtabs(~ combined_pets, data=ds)),
             array(c(10, 10), dim=2,
             dimnames=list(combined_pets=c("Mammals", "Bird"))))
@@ -169,4 +201,21 @@ with_test_authentication({
         expect_identical(names(categories(ds$combined_petloc)),
             c("Mammals", "Bird", "Skipped", "Not Asked"))
     })
+
+    test_that("collapseCategories works on categorical variable", {
+        ds$cat <- factor(rep(c("cat", "Cat", "dog", "aphid"), 5))
+        expect_identical(names(categories(ds$cat)), c("Cat", "aphid", "cat", "dog", "No Data"))
+        ds$cat <- collapseCategories(ds$cat, c("cat", "Cat"), "cat")
+        expect_identical(names(categories(ds$cat)), c("aphid", "cat", "dog", "No Data"))
+        ds$cat <- collapseCategories(ds$cat, c("cat", "aphid"), "nope")
+        expect_identical(names(categories(ds$cat)), c("dog", "No Data", "nope"))
+        ds$cat <- collapseCategories(ds$cat, c("dog", "nope"), "Has Data")
+        expect_identical(names(categories(ds$cat)), c("No Data", "Has Data"))
+        expect_identical(names(table(ds$cat, useNA = "always")), c("No Data", "Has Data"))
+    })
+    test_that("collapseCategories renames variable", {
+        #when length(from) == 1 and to is not present in the categories, the categories are just renamed
+        ds$q1 <- collapseCategories(ds$q1, "Bird", "Tucan")
+        expect_identical(names(categories(ds$q1)), c("Cat", "Dog", "Tucan", "Skipped", "Not Asked"))
+    })
 })
