@@ -1,6 +1,6 @@
 context("Projects")
 
-with_mock_HTTP({
+with_mock_crunch({
     projects <- session()$projects
     test_that("Getting projects catalog", {
         expect_is(projects, "ProjectCatalog")
