@@ -1,6 +1,6 @@
 context("Update a dataset")
 
-with_mock_HTTP({
+with_mock_crunch({
     ds <- loadDataset("test ds")
     test_that("Updating values makes a POST request to the table endpoint", {
         ## TODO: assert the payload shape. This is mainly about exercising code
