@@ -2,21 +2,27 @@ context("All variable metadata")
 
 with_mock_crunch({
     ds <- loadDataset("test ds")
-    test_that("variableMetadata", {
-        vm <- variableMetadata(ds)
+    vm <- variableMetadata(ds)
+    genders <- categories(ds$gender)
+    test_that("variableMetadata exists, is a catalog", {
         expect_is(vm, "VariableCatalog")
         expect_identical(aliases(vm), aliases(allVariables(ds)))
-        expect_identical(Categories(data=vm[[which(aliases(vm) == "gender")]]$categories),
-            categories(ds$gender))
         mymr <- index(vm)[[which(aliases(vm) == "mymrset")]]
         expect_identical(mymr$subvariables,
             c("https://app.crunch.io/api/datasets/1/variables/mymrset/subvariables/subvar2/",
             "https://app.crunch.io/api/datasets/1/variables/mymrset/subvariables/subvar1/",
             "https://app.crunch.io/api/datasets/1/variables/mymrset/subvariables/subvar3/"))
-        expect_identical(mymr$subreferences,
-            list(list(name="First", alias="subvar2", description=NULL),
-                list(name="Second", alias="subvar1", description=NULL),
-                list(name="Last", alias="subvar3", description=NULL)))
+    })
+})
+
+httpcache::clearCache()
+without_internet({
+    test_that("Getting categories and subvariables from variableMetadata doesn't make a request", {
+        ds2 <- ds
+        ds2@variables <- vm
+        expect_identical(categories(ds2$gender), genders)
+        expect_identical(names(subvariables(ds2$mymrset)),
+            c("First", "Second", "Last"))
     })
 })
 
