@@ -1,6 +1,6 @@
 context("Versions")
 
-with_mock_HTTP({
+with_mock_crunch({
     ds <- loadDataset("test ds")
     test_that("Version catalog exists", {
         expect_is(versions(ds), "VersionCatalog")
